@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -28,7 +28,7 @@ class LIBIMPORTWIZARD_EXPORT AbstractCalendar : public LibImportWizard::Abstract
     Q_OBJECT
 public:
     AbstractCalendar();
-    virtual ~AbstractCalendar();
+    ~AbstractCalendar() override;
 
 protected:
     void addEvenViewConfig(const QString &groupName, const QString &key, const QString &value);
